pub enum DataType {
Json,
ProbablyJson,
Urlencoded,
Headers,
}Expand description
enum mainly created for the correct json parsing
Variants
Json
we need a different data type for json because some json values can be used without quotes (numbers, booleans, ..) and therefore this type should be treated differently
ProbablyJson
that’s from parsed request’s content-type header needs to be ignored in case the injection points not within the body to exclude false positive /?{“ZXxZPLN”:“ons9XDZ”, ..} or Cookie: {“ZXxZPLN”:“ons9XDZ”, ..} queries
Urlencoded
Headers